@@ -39,6 +39,13 @@ def saveEnsemble(ensemble, filename=None, **kwargs):
     if isinstance(ensemble, PDBEnsemble):
         attr_list.append('_labels')
         attr_list.append('_trans')
+    elif isinstance(ensemble, ClustENM):
+        attr_list.extend(['_ph', '_cutoff', '_gamma', '_n_modes', '_n_confs',
+                          '_rmsd', '_n_gens', '_maxclust', '_threshold', '_sol',
+                          '_padding', '_ionicStrength', '_force_field', '_tolerance',
+                          '_maxIterations', '_sim', '_temp', '_t_steps', '_outlier',
+                          '_mzscore', '_v1', '_parallel', '_idx_cg', '_n_cg', '_cycle',
+                          '_time', '_targeted', '_tmdk'])
 
     if filename is None:
         filename = ensemble.getTitle().replace(' ', '_')
@@ -104,7 +111,10 @@ def loadEnsemble(filename, **kwargs):
     try:
         title = attr_dict['_title']
     except KeyError:
-        title = attr_dict['_name']
+        try:
+            title = attr_dict['_name']
+        except KeyError:
+            title = None
             
     if isinstance(title, np.ndarray):
         title = title.item()
@@ -117,6 +127,8 @@ def loadEnsemble(filename, **kwargs):
 
     if type_ == 'PDBEnsemble':
         ensemble = PDBEnsemble(title)
+    elif type_ == 'ClustENM':
+        ensemble = ClustENM(title)
     else:
         ensemble = Ensemble(title)
 
@@ -140,6 +152,17 @@ def loadEnsemble(filename, **kwargs):
         if '_msa' in attr_dict.files:
             ensemble._msa = attr_dict['_msa'][0]
     else:
+        if type_ == 'ClustENM':
+            attrs = ['_ph', '_cutoff', '_gamma', '_n_modes', '_n_confs',
+                    '_rmsd', '_n_gens', '_maxclust', '_threshold', '_sol',
+                    '_sim', '_temp', '_t_steps', '_outlier', '_mzscore', '_v1',
+                    '_parallel', '_idx_ca', '_n_ca', '_cycle', '_time', '_targeted',
+                    '_tmdk']
+            
+            for attr in attrs:
+                if attr in attr_dict.files:
+                    setattr(ensemble, attr, attr_dict[attr])
+ 
         ensemble.addCoordset(confs)
         if weights is not None:
             ensemble.setWeights(weights)
@@ -243,7 +266,8 @@ def trimPDBEnsemble(pdb_ensemble, occupancy=None, **kwargs):
             msa = pdb_ensemble.getMSA()
             if msa:
                 msa = msa[:, torf]
-            trimmed.addCoordset(confs[:, torf], weights[:, torf], labels, sequence=msa)
+            trans = pdb_ensemble._trans
+            trimmed.addCoordset(confs[:, torf], weights[:, torf], labels, sequence=msa, transformation=trans)
     else:
         indices = np.where(torf)[0]
         selids = pdb_ensemble._indices
@@ -263,7 +287,8 @@ def trimPDBEnsemble(pdb_ensemble, occupancy=None, **kwargs):
             weights = copy(pdb_ensemble._weights)
             labels = pdb_ensemble.getLabels()
             msa = pdb_ensemble._msa
-            trimmed.addCoordset(confs, weights, labels, sequence=msa)
+            trans = pdb_ensemble._trans
+            trimmed.addCoordset(confs, weights, labels, sequence=msa, transformation=trans)
 
         trimmed.setAtoms(select)
 
@@ -737,4 +762,4 @@ def alignByEnsemble(atomics, ensemble):
     if len(output) == 1:
         return output[0]
     else:
-        return output
\ No newline at end of file
+        return output
